@@ -26,7 +26,7 @@
 
 extern const char *minor_str[];
 
-#define VERSION "v5.7"
+#define VERSION "v5.8"
 
 #undef DO_FLUSHCACHE		/* under construction: force cache flush on -W0 */
 
@@ -910,10 +910,9 @@ void process_dev (char *devname)
 			printf(" setting drive write-caching to %ld", wcache);
 			on_off(wcache);
 		}
-#ifdef DO_FLUSHCACHE
-		if (!wcache && ioctl(fd, HDIO_DRIVE_CMD, &flushcache))
-			perror (" HDIO_DRIVE_CMD(flushcache) failed");
-#endif /* DO_FLUSHCACHE */
+#ifdef HDIO_SET_WCACHE
+		if (!ioctl(fd, HDIO_SET_WCACHE, wcache))
+#endif
 		if (ioctl(fd, HDIO_DRIVE_CMD, &args))
 			perror(" HDIO_DRIVE_CMD(setcache) failed");
 #ifdef DO_FLUSHCACHE
@@ -982,7 +981,7 @@ void process_dev (char *devname)
 	if (verbose || get_mult || get_identity) {
 		multcount = -1;
 		if (ioctl(fd, HDIO_GET_MULTCOUNT, &multcount)) {
-			if (verbose || get_mult)
+			if (get_mult)
 				perror(" HDIO_GET_MULTCOUNT failed");
 		} else if (verbose | get_mult) {
 			printf(" multcount    = %2ld", multcount);
@@ -1230,11 +1229,22 @@ identify_abort:	;
 	close (fd);
 }
 
-void usage_error (void)
+void usage_error (int out)
 {
-	fprintf(stderr,"\n%s - get/set hard disk parameters - version %s\n\n", progname, VERSION);
-	fprintf(stderr,"Usage:  %s  [options] [device] ..\n\n", progname);
-	fprintf(stderr,"Options:\n"
+        FILE *desc;
+        int ret;
+
+        if (out == 0) {
+            desc = stdout;
+            ret = 0;
+        } else {
+            desc = stderr;
+            ret = 1;
+        }
+
+	fprintf(desc,"\n%s - get/set hard disk parameters - version %s\n\n", progname, VERSION);
+	fprintf(desc,"Usage:  %s  [options] [device] ..\n\n", progname);
+	fprintf(desc,"Options:\n"
 	" -a   get/set fs readahead\n"
 #ifdef HDIO_DRIVE_CMD
 	" -A   set drive read-lookahead flag (0/1)\n"
@@ -1316,7 +1326,7 @@ void usage_error (void)
 	" -z   re-read partition table\n"
 #endif
 	);
-	exit(1);
+	exit(ret);
 }
 
 #define GET_NUMBER(flag,num)	num = 0; \
@@ -1392,7 +1402,7 @@ int main(int argc, char **argv)
 	++argv;
 
 	if (!--argc)
-		usage_error();
+		usage_error(1);
 	while (argc--) {
 		p = *argv++;
 		if (*p == '-') {
@@ -1409,7 +1419,7 @@ int main(int argc, char **argv)
 				continue;
 			}
 			if (!*++p)
-				usage_error();
+				usage_error(1);
 			while ((c = *p++)) {
 				++flagcount;
 				switch (c) {
@@ -1749,12 +1759,13 @@ int main(int argc, char **argv)
 						break;
 #endif /* HDIO_GET_ACOUSTIC */
 					case 'h':
+						usage_error(0);
 					default:
-						usage_error();
+						usage_error(1);
 				}
 			}
 			if (!argc)
-				usage_error();
+				usage_error(1);
 		} else {
 			process_dev (p);
 		}
