@@ -13,7 +13,7 @@
    intentional. */
 extern void identify (__u16 *id_supplied, const char *devname);
 
-extern void usage_error(void)    __attribute__((noreturn));
+extern void usage_error(int out)    __attribute__((noreturn));
 extern int main(int argc, char **argv) __attribute__((noreturn));
 extern void flush_buffer_cache (int fd);
 extern int seek_to_zero (int fd);
