@@ -426,11 +426,7 @@ void identify (__u16 *id_supplied, const char *devname)
 	__u64 bb, bbbig; /* (:) */
 
 	if (id_supplied) {
-#if __BYTE_ORDER == __BIG_ENDIAN
-		swab(id_supplied, val, sizeof(val));
-#else
 		memcpy(val, id_supplied, sizeof(val));
-#endif
 	} else {
 		id_file = calloc(1, strlen(devname)+1+strlen(fmt));
 		sprintf(id_file, fmt, devname);
@@ -681,15 +677,15 @@ void identify (__u16 *id_supplied, const char *devname)
 				        (__u64)val[LBA_48_MSB] << 32 |
 				        (__u64)val[LBA_MID] << 16 | 
 					val[LBA_LSB] ;
-				printf("\tLBA48  user addressable sectors:%11llu\n",bbbig);
+				printf("\tLBA48  user addressable sectors:%11llu\n", (unsigned long long)bbbig);
 			}
 		}
 		if (!bbbig) bbbig = (__u64)(ll>mm ? ll : mm); /* # 512 byte blocks */
 		if (!bbbig) bbbig = bb;
-		printf("\tdevice size with M = 1024*1024: %11llu MBytes\n",bbbig>>11);
+		printf("\tdevice size with M = 1024*1024: %11llu MBytes\n", (unsigned long long)(bbbig>>11));
 		bbbig = (bbbig<<9)/1000000;
-		printf("\tdevice size with M = 1000*1000: %11llu MBytes ",bbbig);
-		if(bbbig > 1000) printf("(%llu GB)\n",bbbig/1000);
+		printf("\tdevice size with M = 1000*1000: %11llu MBytes ", (unsigned long long)bbbig);
+		if(bbbig > 1000) printf("(%llu GB)\n", (unsigned long long)(bbbig/1000));
 		else printf("\n");
 
 	}
